@@ -248,335 +248,6 @@ string_number_end:
     RETURNAGAIN (newSVpv (start, (char *) parser->end - start));
 }
 
-#if 0
-
-/* Turn a number into an SV. */
-
-static INLINE SVPTR
-PREFIX(number) (parser_t * parser)
-{
-    /* Various parsing flags. */
-
-    /* Set to 1 if we saw ".". */
-
-    int dot;
-
-    /* Set to 1 if we saw digits after ".". */
-
-    int dotdigits;
-
-    /* Set to 1 if we saw "e" or "E". */
-
-    int exp;
-
-    /* Set to 1 if we saw "+". */
-
-    int plus;
-
-    /* Set to 1 if we saw a leading zero. */
-
-    int zero;
-
-    /* Set to 1 if we saw a leading "-". */
-
-    int minus;
-
-    /* Set to 1 if we saw a "-" after we saw "e" or "E". */
-
-    int expminus;
-
-    int newexp;
-
-    int expdigits;
-
-    /* End marker for strtod/strtol. */
-
-    char * end;
-
-    /* Start marker for strtod/strtol. */
-
-    char * start;
-
-    /* A guess for integer numbers. */
-
-    int guess;
-
-    /* The parsed character itself, the cause of our motion. */
-
-    char c;
-
-    /* Set all the flags to zero. */
-
-    dot = 0;
-    dotdigits = 0;
-    exp = 0;
-    plus = 0;
-    zero = 0;
-    minus = 0;
-    expminus = 0;
-    guess = 0;
-    zero = 0;
-    newexp = 0;
-    expdigits = 0;
-
-    parser->end--;
-    start = parser->end;
-
-#define FAILNUMBER(err)				\
-    parser->bad_byte = parser->end - 1;		\
-    parser->error = json_error_ ## err;		\
-    parser->bad_type = json_number;		\
-    parser->bad_beginning = start;		\
-    failbadinput (parser)
-
- number_start:
-
-    switch (NEXTBYTE) {
-
-    case '.':
-
-	if (dot) {
-	    parser->expected = XDIGIT;
-	    FAILNUMBER (unexpected_character);
-	}
-	if (exp || (! zero && ! guess)) {
-	    parser->expected = XDIGIT | XMINUS;
-	    FAILNUMBER (unexpected_character);
-	}
-	dot = 1;
-	goto number_start;
-
-    case '+':
-
-	/* JSON doesn't allow a "useless plus" at the start of
-	   numbers: "A number contains an integer component that may
-	   be prefixed with an optional minus sign", although it does
-	   allow them inside exponentials: "An exponent part begins
-	   with the letter E in upper or lowercase, which may be
-	   followed by a plus or minus sign." (quotes from Section 2.4
-	   of RFC 4627, the JSON standard.) */
-
-	if (! newexp) {
-	    parser->expected = XDIGIT;
-	    FAILNUMBER (unexpected_character);
-	}
-	plus = 1;
-	newexp = 0;
-	goto number_start;
-	
-    case '-':
-
-	if (exp) {
-	    if (expminus || ! newexp) {
-		parser->expected = XDIGIT;
-		FAILNUMBER (unexpected_character);
-	    }
-	    expminus = 1;
-	    newexp = 0;
-	    goto number_start;
-	}
-	else {
-	    /* Use "guess" as a flag that we have seen a digit. */
-	    if (minus || guess || zero) {
-		parser->expected = XDIGIT;
-		FAILNUMBER (unexpected_character);
-	    }
-	    minus = 1;
-	    goto number_start;
-	}
-	
-    case 'e':
-    case 'E':
-
-	if (! zero && ! guess && ! dot) {
-	    parser->expected = XDIGIT;
-	    FAILNUMBER (unexpected_character);
-	}
-	if (dot && ! dotdigits) {
-	    parser->expected = XDIGIT;
-	    FAILNUMBER (unexpected_character);
-	}
-	if (exp) {
-	    parser->expected = XDIGIT;
-	    if (newexp) {
-		parser->expected |= XPLUS | XMINUS;
-	    }
-	    FAILNUMBER (unexpected_character);
-	}
-	exp = 1;
-	newexp = 1;
-	goto number_start;
-
-    case '0':
-
-	if (zero && ! dot && ! exp) {
-	    parser->expected = XDOT | XCOMMA | XWHITESPACE | XEXPONENTIAL | XOBJECT_END | XARRAY_END;
-	    FAILNUMBER (unexpected_character);
-	}
-	if (exp) {
-	    newexp = 0;
-	    expdigits = 1;
-	}
-	else {
-	    if (dot) {
-		dotdigits = 1;
-	    }
-	    else {
-		if (guess) {
-		    guess = 10 * guess;
-		}
-		else {
-		    zero = 1;
-		}
-	    }
-	}
-	goto number_start;
-
-    case DIGIT19:
-
-	if (zero && ! dot && ! exp) {
-	    parser->expected = XDOT | XCOMMA | XWHITESPACE | XOBJECT_END | XARRAY_END;
-	    FAILNUMBER (unexpected_character);
-	}
-	if (exp) {
-	    newexp = 0;
-	    expdigits = 1;
-	}
-	else {
-	    if (dot) {
-		dotdigits = 1;
-	    }
-	    else {
-		guess = 10 * guess + (c - '0');
-	    }
-	}
-	goto number_start;
-
-    case WHITESPACE:
-    case ',':
-    case ']':
-    case '}':
-
-	if (minus && ! guess) {
-	    parser->expected = XDIGIT;
-	    FAILNUMBER (unexpected_character);
-	}
-
-	/* JSON RFC: "The E and optional sign are followed by one or
-	   more digits." So if we have an E and no digits or anything
-	   else, barf. */
-
-	if ((exp && ! expdigits) ||
-	    (dot && ! dotdigits)) {
-	    parser->expected = XDIGIT;
-	    if (newexp) {
-		parser->expected |= XPLUS | XMINUS;
-	    }
-	    FAILNUMBER (unexpected_character);
-	}
-
-	/* We read a byte which wasn't part of a number, so reject it
-	   and let the next thing to work out what to do with it. */
-
-	parser->end--;
-	break;
-
-    default:
-
-	if (minus && ! guess) {
-	    parser->expected = XDIGIT;
-	    FAILNUMBER (unexpected_character);
-	}
-
-	/* JSON RFC: "The E and optional sign are followed by one or
-	   more digits." So if we have an E and no digits or anything
-	   else, barf. */
-
-	if ((exp && ! expdigits) || (dot && ! dotdigits)) {
-	    parser->expected = XDIGIT;
-	    if (newexp) {
-		parser->expected |= XPLUS | XMINUS;
-	    }
-	    FAILNUMBER (unexpected_character);
-	}
-	else {
-	    /* This looks a bit strange but we can accept a comma or
-	       whitespace or the end of an object or array as the end of a
-	       number. */
-	    parser->expected = XCOMMA | XWHITESPACE;
-	    if (zero) {
-		if (dot) {
-		    parser->expected |= XDIGIT;
-		}
-		else {
-		    if (exp) {
-			/* 0e0 is legal */
-			parser->expected |= XDIGIT;
-		    }
-		    else {
-			/* 0e is legal */
-			parser->expected |= XEXPONENTIAL;
-		    }		    
-		}
-	    }
-	    else {
-		parser->expected |= XDIGIT;
-	    }
-	    if ((guess || dotdigits) && ! exp) {
-		parser->expected |= XEXPONENTIAL;
-	    }
-	    if (! exp && ! dot && (zero || guess)) {
-		parser->expected |= XDOT;
-	    }
-	    if (newexp) {
-		parser->expected |= XPLUS | XMINUS;
-	    }
-	    FAILNUMBER (unexpected_character);
-	}
-    }
-
-    if (dot || exp) {
-
-	/* This is a floating point number, so we send it to
-	   "strtod". */
-
-	double d;
-	d = strtod (start, & end);
-	if (end == parser->end) {
-	    RETURNAGAIN (newSVnv (d));
-	}
-	else {
-	    /* Oops, Marc Lehmann was right all along. */
-	    failbug (__FILE__, __LINE__, parser,
-		     "unable to parse '%.*s' with strtod",
-		     parser->end - start, start);
-	}
-    }
-    else {
-	/* If the number has less than INT_MAX_DIGITS, we guess that
-	   it will fit inside a Perl integer, so we don't bother doing
-	   any more parsing. This is a trick to increase the speed of
-	   parsing integer numbers with a small number of digits. */
-
-	if (parser->end - start < INT_MAX_DIGITS + minus) {
-	    if (minus) {
-		guess = -guess;
-	    }
-	    RETURNAGAIN (newSViv (guess));
-	}
-    }
-
-    /* We could not convert this number using a number conversion
-       routine, so we are going to convert it to a string.  This might
-       happen with ridiculously long numbers or something. The JSON
-       standard doesn't explicitly disallow integers with a million
-       digits. */
-
-    RETURNAGAIN (newSVpv (start, parser->end - start));
-}
-
-#endif /* 0 */
-
 static SVPTR
 PREFIX(string) (parser_t * parser)
 {
